PESummary postprocessing
========================

PESummary is used by some analysis pipelines for postprocessing gravitational wave parameter estimation samples.

The PESummary package implements a large amount of post-processing functionality, not all of which is implemented in asimov at present, but in these documentation we'll describe how you can configure the funcitonality which is available.

Pipelines which support PESummary post-processing will automatically run PESummary when asimov detects that the main analysis job is completed, so no additional configuration is usually required just to run this step.


